@@ -1,21 +1,7 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef MAPS_H
@@ -25,12 +11,11 @@
 #include <QMap>
 #include <QObject>
 
-#include <pulse/pulseaudio.h>
 #include <pulse/ext-stream-restore.h>
+#include <pulse/pulseaudio.h>
 
 namespace QPulseAudio
 {
-
 // Used for typedefs.
 class Card;
 class Client;
@@ -72,9 +57,14 @@ template<typename Type, typename PAInfo>
 class MapBase : public MapBaseQObject
 {
 public:
-    ~MapBase() override {}
+    ~MapBase() override
+    {
+    }
 
-    const QMap<quint32, Type *> &data() const { return m_data; }
+    const QMap<quint32, Type *> &data() const
+    {
+        return m_data;
+    }
 
     int count() const override
     {
