@@ -1,41 +1,26 @@
 /*
-    Copyright 2014-2015 Harald Sitter <sitter@kde.org>
-    Copyright 2016 David Rosca <nowrep@gmail.com>
+    SPDX-FileCopyrightText: 2014-2015 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2016 David Rosca <nowrep@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "pulseaudio.h"
 
-#include "debug.h"
 #include "card.h"
+#include "debug.h"
+#include "module.h"
+#include "server.h"
 #include "sink.h"
 #include "sinkinput.h"
 #include "source.h"
 #include "sourceoutput.h"
-#include "server.h"
 #include "streamrestore.h"
-#include "module.h"
 
 #include <QMetaEnum>
 
 namespace QPulseAudio
 {
-
 AbstractModel::AbstractModel(const MapBaseQObject *map, QObject *parent)
     : QAbstractListModel(parent)
     , m_map(map)
@@ -62,8 +47,8 @@ AbstractModel::AbstractModel(const MapBaseQObject *map, QObject *parent)
 
 AbstractModel::~AbstractModel()
 {
-    //deref context after we've deleted this object
-    //see https://bugs.kde.org/show_bug.cgi?id=371215
+    // deref context after we've deleted this object
+    // see https://bugs.kde.org/show_bug.cgi?id=371215
     Context::instance()->unref();
 }
 
@@ -95,7 +80,7 @@ QVariant AbstractModel::data(const QModelIndex &index, int role) const
     if (role == PulseObjectRole) {
         return QVariant::fromValue(data);
     } else if (role == Qt::DisplayRole) {
-        return static_cast<PulseObject*>(data)->properties().value(QStringLiteral("name")).toString();
+        return static_cast<PulseObject *>(data)->properties().value(QStringLiteral("name")).toString();
     }
     int property = m_objectProperties.value(role, -1);
     if (property == -1) {
@@ -201,8 +186,8 @@ void AbstractModel::onDataAdded(int index)
     QObject *data = m_map->objectAt(index);
     const QMetaObject *mo = data->metaObject();
     // We have all the data changed notify signals already stored
-    auto keys = m_signalIndexToProperties.keys();
-    Q_FOREACH (int index, keys) {
+    const auto keys = m_signalIndexToProperties.keys();
+    for (const int index : keys) {
         QMetaMethod meth = mo->method(index);
         connect(data, meth, this, propertyChangedMetaMethod());
     }
@@ -299,8 +284,7 @@ Sink *SinkModel::findPreferredSink() const
         QMapIterator<quint32, Sink *> it(context()->sinks().data());
         while (it.hasNext()) {
             it.next();
-            if ((it.value()->isVirtualDevice() && !it.value()->isDefault())
-                    || it.value()->state() != state) {
+            if ((it.value()->isVirtualDevice() && !it.value()->isDefault()) || it.value()->state() != state) {
                 continue;
             }
             if (!ret) {
