@@ -1,23 +1,9 @@
 /*
-    Copyright 2019 Kai Uwe Broulik <kde@privat.broulik.de>
-    Copyright 2020 MBition GmbH,
+    SPDX-FileCopyrightText: 2019 Kai Uwe Broulik <kde@privat.broulik.de>
+    SPDX-FileCopyrightText: 2020 MBition GmbH
         Author: Kai Uwe Broulik <kai_uwe.broulik@mbition.io>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "microphoneindicator.h"
@@ -45,7 +31,6 @@ MicrophoneIndicator::MicrophoneIndicator(QObject *parent)
     , m_sourceOutputModel(new SourceOutputModel(this))
     , m_updateTimer(new QTimer(this))
 {
-
     connect(m_sourceModel, &QAbstractItemModel::rowsInserted, this, &MicrophoneIndicator::scheduleUpdate);
     connect(m_sourceModel, &QAbstractItemModel::rowsRemoved, this, &MicrophoneIndicator::scheduleUpdate);
     connect(m_sourceModel, &QAbstractItemModel::dataChanged, this, &MicrophoneIndicator::scheduleUpdate);
@@ -146,7 +131,7 @@ void MicrophoneIndicator::update()
 
     m_sni->setTitle(i18n("Microphone"));
     m_sni->setIconByName(iconName);
-    m_sni->setToolTip(QIcon::fromTheme(iconName), i18n("Microphone"), toolTipForApps(apps));
+    m_sni->setToolTip(QIcon::fromTheme(iconName), allMuted ? i18n("Microphone Muted") : i18n("Microphone"), toolTipForApps(apps));
 
     if (m_muteAction) {
         m_muteAction->setChecked(allMuted);
@@ -227,8 +212,8 @@ void MicrophoneIndicator::adjustVolume(int direction)
 
     const int step = qRound(5 * Context::NormalVolume / 100.0);
 
-    const auto newVolume = qBound(Context::MinimalVolume,
-                                  source->volume() + direction * step,
+    const auto newVolume = qBound(Context::MinimalVolume, //
+                                  source->volume() + direction * step, //
                                   Context::NormalVolume);
 
     source->setVolume(newVolume);
@@ -254,7 +239,6 @@ void MicrophoneIndicator::showOsd()
     }
 
     m_osd->showMicrophone(volumePercent(preferredSource));
-
 }
 
 QVector<QModelIndex> MicrophoneIndicator::recordingApplications() const
