@@ -21,6 +21,7 @@
 #include "globalactioncollection.h"
 #include "listitemmenu.h"
 #include "microphoneindicator.h"
+#include "speakertest.h"
 #include "volumefeedback.h"
 #include "volumeosd.h"
 
@@ -37,6 +38,8 @@ static QJSValue pulseaudio_singleton(QQmlEngine *engine, QJSEngine *scriptEngine
 
 void Plugin::registerTypes(const char *uri)
 {
+    QPulseAudio::Context::setApplicationId(QStringLiteral("org.kde.plasma-pa"));
+
     qmlRegisterType<QPulseAudio::CardModel>(uri, 0, 1, "CardModel");
     qmlRegisterType<QPulseAudio::SinkModel>(uri, 0, 1, "SinkModel");
     qmlRegisterType<QPulseAudio::SinkInputModel>(uri, 0, 1, "SinkInputModel");
@@ -54,6 +57,7 @@ void Plugin::registerTypes(const char *uri)
     qmlRegisterType<ListItemMenu>(uri, 0, 1, "ListItemMenu");
     qmlRegisterType<VolumeOSD>(uri, 0, 1, "VolumeOSD");
     qmlRegisterType<VolumeFeedback>(uri, 0, 1, "VolumeFeedback");
+    qmlRegisterType<SpeakerTest>(uri, 0, 1, "SpeakerTest");
     qmlRegisterSingletonType(uri, 0, 1, "PulseAudio", pulseaudio_singleton);
     qmlRegisterSingletonType<MicrophoneIndicator>(uri, 0, 1, "MicrophoneIndicator", [](QQmlEngine *engine, QJSEngine *jsEngine) -> QObject * {
         Q_UNUSED(engine);
