@@ -24,10 +24,6 @@ void SinkInput::update(const pa_sink_input_info *info)
         m_deviceIndex = info->sink;
         Q_EMIT deviceIndexChanged();
     }
-    if (m_sinkIndex != info->sink) {
-        m_sinkIndex = info->sink;
-        Q_EMIT sourceIndexChanged();
-    }
 }
 
 void SinkInput::setDeviceIndex(quint32 deviceIndex)
@@ -55,18 +51,4 @@ void SinkInput::setChannelVolumes(const QVector<qint64> &channelVolumes)
     context()->setGenericVolumes(index(), channelVolumes, cvolume(), &pa_context_set_sink_input_volume);
 }
 
-quint32 SinkInput::sourceIndex() const
-{
-    auto sink = qobject_cast<Sink *>(context()->sinks().data().value(m_sinkIndex));
-    if (!sink) {
-        return -1;
-    }
-    return sink->sourceIndex();
-}
-
-quint32 SinkInput::streamIndex() const
-{
-    return m_index;
-}
-
 } // QPulseAudio
